#!/usr/local/bin/perl -w
# head.pl version 0.1

#### LAST UPDATED: Oct19, 2002 ####
###########################################################################
#
# This program lists all `<head...>...</head>' instances in the  
# source file.
#
# USAGE : head.pl [OPTIONS] SOURCE > DESTINATION
#
###########################################################################

# Copyright (C) 2000-2002
# Ted Pedersen, University of Minnesota, Duluth
# tpederse@d.umn.edu
# Mohammad Saif, University of Minnesota, Duluth
# moha0149@d.umn.edu
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

# START OF PROGRAM
use Getopt::Long;

# check if command line options have been provided
# If not print usage information
if ( $#ARGV == -1 )
{
    &usage();
    exit;
}

# Check if any options specified
GetOptions("version", "help");
if ( defined $opt_help )    { $help = $opt_help; }
else                        { $help = 0; }
# Print help if asked
if ( $help )
{
    &help();
    exit;
}
# if version has been requested, show version
if ( defined $opt_version )
{
    $opt_version = 1;
    &showVersion();
    exit;
}


# Read lines from SOURCE file line by line
while (<>) 
{
    #ch
    if (/(<instance id=[^>]+>)/)
    {
        print "$1  ";
    }

    # Check if line has a head word instance
    if (/.*(<head[^>]*>.*<\/head>).*/) 
    {
	print "$1\n";
    }
}

# Subroutine to print help message
sub help
{
    print "Usage: head.pl [OPTIONS] SOURCE > DESTINATION\n\n";
    print "This program lists all `<head...>...</head>' instances in the SOURCE file. It may be used with an initial source file and the final part of speech tagged file ro make sure that the number of head words is the same after the processing of the data. The data should match both in number and what they hold.\n\n";
    
    print "OPTIONS:\n\n";
    print "  --help             Prints the help message.\n";
    print "  --version          Prints the version number.\n\n";
}

sub usage
{
    print "Usage: head.pl [OPTIONS] SOURCE > DESTINATION\n";
    AskHelp();
}
# Message describing way to get help
sub AskHelp
{
    print "Type head.pl --help for help.\n";
}
# function to output the version number
sub showVersion
{
    print STDERR "head.pl      -        version 0.1\n";
    print STDERR "A component of posSenseval version 0.1\n";
    print STDERR "Copyright (C) 2000-2003, Saif Mohammad Ted Pedersen\n";
}

